package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````*",```````!``````````,"A````
M`````````$``.``(`$``&0`8``8````%````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````"R4````````+)0`````````
M``$```````$````&````*)L````````HFP$``````"B;`0``````6`4`````
M``"`%0```````````0```````@````8````XFP```````#B;`0``````.)L!
M```````@`@```````"`"````````"``````````$````!````!P"````````
M'`(````````<`@```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0````HFP```````"B;`0``````*)L!``````#8!```````
M`-@$`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4`=,N#I+6LOE"WT%#[$W2#<>H#-OP1````4`````0````(````(1`0``7`
M!(0H`A`!@(9`@((I``0)(`2)B*`81;H$`@A0````40```%4```!:````6P``
M`&(```!C````9````&8```!G`````````&D```!J````:P```&T`````````
M``````&O-.ANQ=\?ZM/O#L[>1RUK?YI\+L6;MG94/)0@_^0.N(WQ#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M`````````````````````````````P`+`*`<````````````````````````
M`P`5``"@`0````````````````"]`@``$@````````````````````````!!
M`P``$@````````````````````````"-`@``$@``````````````````````
M``"4`@``$@`````````````````````````S`P``$@``````````````````
M```````V`@``$@`````````````````````````1````(```````````````
M``````````#E`@``$@````````````````````````#]`@``$@``````````
M```````````````D`P``(@````````````````````````#V`@``$@``````
M``````````````````#=`@``$@````````````````````````"T````$@``
M``````````````````````#O`@``$0````````````````````````"#`0``
M$@`````````````````````````D`@``$@````````````````````````"$
M````$@`````````````````````````,`0``$@``````````````````````
M```&`P``$@````````````````````````!_`@``$@``````````````````
M``````"J`0``$@`````````````````````````!`0``$0``````````````
M``````````#$`@``$@````````````````````````!G`0``$@``````````
M``````````````#C````$0`````````````````````````U`0``$@``````
M```````````````````[`@``$@````````````````````````!7`P``$@``
M``````````````````````";`@``$@````````````````````````#"````
M$@````````````````````````"Q`0``$@`````````````````````````-
M`@``$@````````````````````````">`0``$@``````````````````````
M``#;`0``$@````````````````````````!J`@``$@``````````````````
M``````"&`@``$@````````````````````````!#`@``$@``````````````
M``````````!,`@``$@````````````````````````#O`0``$@``````````
M``````````````!#`0``$@`````````````````````````M````(```````
M``````````````````")`P``$0````````````````````````!J`P``(0``
M``````````````````````!R`@``$@````````````````````````!)`P``
M$@````````````````````````"\`0``$0````````````````````````!D
M````$@````````````````````````"O`@``$@``````````````````````
M``!0`P``$@`````````````````````````(!```$@``````````````````
M``````"I`@``$@````````````````````````"3````$@``````````````
M``````````"?````$@````````````````````````!<`0``$@``````````
M``````````````#2`@``$@`````````````````````````B`0``$@``````
M```````````````````1`0``$@````````````````````````!6````$@``
M```````````````````````:`P``$@`````````````````````````6`0``
M$@````````````````````````"3`0``$@````````````````````````#P
M````$@`````````````````````````3`P``$@``````````````````````
M``!U`0``$@````````````````````````!S````$@``````````````````
M```````5`@``$@````````````````````````!X`@``$@``````````````
M``````````!I`P``$0````````````````````````!K`P``$0``````````
M``````````````#U`0``$@````````````````````````#4````$@``````
M``````````````````!3`0``$@````````````````````````"B`@``$@``
M```````````````````````\````(`````````````````````````#\`0``
M$@````````````````````````!=`@``$@````````````````````````!D
M`@``$@````````````````````````"]`P``$``6`*BP`0``````````````
M```1!```$@`-`*A2````````@`````````#?`P``$@`.`,13````````````
M```````V!```$@`-`/!$````````D`D```````!D`P``$@`-`.`@````````
M2`(```````#E`P``$@`-`-`]````````!`````````"N`P``$``6`("@`0``
M``````````````"D!```$@`-`-@]````````2`(```````">!```$@`+`*`<
M``````````````````#1!```$@`-`(!.````````*`0```````"B`P``$``6
M`("@`0`````````````````=!```$@`-`"!`````````+`````````!0!```
M$0`/`-A3````````!`````````#0`P``$``6`*BP`0````````````````#(
M`P``$``6`*BP`0````````````````"<!```$@`-`&`\````````.```````
M``"Q!```$@`-`.A#````````!`$```````##!```$@`-`#A#````````B```
M``````!#!```$``5``"@`0`````````````````J!```$@`-`%!`````````
M'`$```````";`P``$``5`("@`0````````````````"%!```$0`5`'B@`0``
M````"`````````#5`P``$@`-`,!3````````!`````````!U!```$@`-`$A3
M````````>`````````!)!```$@`-`"@C``````````````````!%!```(``5
M``"@`0````````````````#V`P``$@`-`,!#````````*`````````"\`P``
M$``6`*BP`0````````````````!?!```$@`-`/`\````````W`````````"/
M!```$@`-`'!!````````Q`$`````````;&EB<&5R;"YS;RXU+C(V`%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S
M=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?
M,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE
M=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP
M=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F
M971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M
M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)P=&AR96%D+G-O
M+C``<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L
M;V-A=&EO;@!L<V5E:S8T`')E860`;&EB8RYS;RXV`%]?<F5G:7-T97)?871F
M;W)K`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N
M;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R9'5P
M`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?
M8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?
M7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`
M<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK
M`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N
M=FER;VX`;&0M;&EN=7@M86%R8V@V-"YS;RXQ`%]?<W1A8VM?8VAK7V=U87)D
M`%]E9&%T80!?7V)S<U]S=&%R=`!?7V)S<U]S=&%R=%]?`%]?8G-S7V5N9%]?
M`%]?96YD7U\`7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE
M8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?
M8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R
M=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C
M7V-S=5]I;FET`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?
M9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U])
M;G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXQ-P`````````"``(``@`"``(`
M`@````(``@`"``(``@````(````"```````"``(``@````(``````````@`"
M``(```````,````#``(``@`"``(``P``````!``"``(``@```````@`"``(`
M`@`````````"`````@````(``````````@```````P`"``(``@`#```````"
M`````P`"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$````!``$`<P,``!`````@````EY&6
M!@``!`#G!`````````$``0#+`0``$````"````"7D98&```#`.<$````````
M`0`!`!H"```0`````````)>1E@8```(`YP0````````HFP$```````,$````
M````*"0````````PFP$```````,$````````X",```````!XGP$```````,$
M````````P%,```````#`GP$```````,$````````"*`!``````#0GP$`````
M``,$````````2%,```````#@GP$```````,$````````X"`````````(H`$`
M``````,$````````"*`!```````8H`$```````,$````````Z%<````````@
MH`$```````,$````````&%0````````PH`$```````,$````````>%4`````
M```XH`$```````,$````````R%<```````!`H`$```````,$````````T%<`
M``````!(H`$```````,$````````V%<```````!0H`$```````,$````````
MX%<```````!@H`$```````,$````````L%<```````!HH`$```````,$````
M````N%<```````!XH`$```````,$````````\%<```````"`GP$```````$$
M```)``````````````"(GP$```````$$```,``````````````"0GP$`````
M``$$```0``````````````"8GP$```````$$```1``````````````"@GP$`
M``````$$```8``````````````"HGP$```````$$```;``````````````"P
MGP$```````$$```K``````````````"XGP$```````$$```L````````````
M``#(GP$```````$$```P``````````````#8GP$```````$$```Z````````
M``````#HGP$```````$$``!#``````````````#PGP$```````$$``!'````
M``````````#XGP$```````$$``!,``````````````!PG0$```````($```#
M``````````````!XG0$```````($```$``````````````"`G0$```````($
M```%``````````````"(G0$```````($```&``````````````"0G0$`````
M``($```'``````````````"8G0$```````($```(``````````````"@G0$`
M``````($```*``````````````"HG0$```````($```+``````````````"P
MG0$```````($```,``````````````"XG0$```````($```-````````````
M``#`G0$```````($```.``````````````#(G0$```````($```/````````
M``````#0G0$```````($```2``````````````#8G0$```````($```3````
M``````````#@G0$```````($```4``````````````#HG0$```````($```5
M``````````````#PG0$```````($```6``````````````#XG0$```````($
M```7````````````````G@$```````($```9```````````````(G@$`````
M``($```:```````````````0G@$```````($```<```````````````8G@$`
M``````($```=```````````````@G@$```````($```>```````````````H
MG@$```````($```?```````````````PG@$```````($```@````````````
M```XG@$```````($```A``````````````!`G@$```````($```B````````
M``````!(G@$```````($```C``````````````!0G@$```````($```D````
M``````````!8G@$```````($```E``````````````!@G@$```````($```F
M``````````````!HG@$```````($```G``````````````!PG@$```````($
M```H``````````````!XG@$```````($```I``````````````"`G@$`````
M``($```J``````````````"(G@$```````($```K``````````````"0G@$`
M``````($```N``````````````"8G@$```````($```O``````````````"@
MG@$```````($```Q``````````````"HG@$```````($```R````````````
M``"PG@$```````($```S``````````````"XG@$```````($```T````````
M``````#`G@$```````($```U``````````````#(G@$```````($```V````
M``````````#0G@$```````($```W``````````````#8G@$```````($```X
M``````````````#@G@$```````($```Y``````````````#HG@$```````($
M```[``````````````#PG@$```````($```\``````````````#XG@$`````
M``($```]````````````````GP$```````($```^```````````````(GP$`
M``````($```_```````````````0GP$```````($``!````````````````8
MGP$```````($``!!```````````````@GP$```````($``!"````````````
M```HGP$```````($``!$```````````````PGP$```````($``!%````````
M```````XGP$```````($``!(``````````````!`GP$```````($``!)````
M``````````!(GP$```````($``!*``````````````!0GP$```````($``!+
M``````````````!8GP$```````($``!-``````````````!@GP$```````($
M``!.``````````````!HGP$```````($``!/``````````````#]>[^I_0,`
MD:X!`)3]>\&HP`-?U@```````````````/![OZG0``"0$;9&^1"B-9$@`A_6
M'R`#U1\@`]4?(`/5T```D!&Z1OD0PC61(`(?UM```)`1OD;Y$.(UD2`"'];0
M``"0$<)&^1`"-I$@`A_6T```D!'&1OD0(C:1(`(?UM```)`1RD;Y$$(VD2`"
M'];0``"0$<Y&^1!B-I$@`A_6T```D!'21OD0@C:1(`(?UM```)`1UD;Y$*(V
MD2`"'];0``"0$=I&^1#"-I$@`A_6T```D!'>1OD0XC:1(`(?UM```)`1XD;Y
M$`(WD2`"'];0``"0$>9&^1`B-Y$@`A_6T```D!'J1OD00C>1(`(?UM```)`1
M[D;Y$&(WD2`"'];0``"0$?)&^1""-Y$@`A_6T```D!'V1OD0HC>1(`(?UM``
M`)`1^D;Y$,(WD2`"'];0``"0$?Y&^1#B-Y$@`A_6T```D!$"1_D0`CB1(`(?
MUM```)`1!D?Y$"(XD2`"'];0``"0$0I'^1!".)$@`A_6T```D!$.1_D08CB1
M(`(?UM```)`1$D?Y$((XD2`"'];0``"0$19'^1"B.)$@`A_6T```D!$:1_D0
MPCB1(`(?UM```)`1'D?Y$.(XD2`"'];0``"0$2)'^1`".9$@`A_6T```D!$F
M1_D0(CF1(`(?UM```)`1*D?Y$$(YD2`"'];0``"0$2Y'^1!B.9$@`A_6T```
MD!$R1_D0@CF1(`(?UM```)`1-D?Y$*(YD2`"'];0``"0$3I'^1#".9$@`A_6
MT```D!$^1_D0XCF1(`(?UM```)`10D?Y$`(ZD2`"'];0``"0$49'^1`B.I$@
M`A_6T```D!%*1_D00CJ1(`(?UM```)`13D?Y$&(ZD2`"'];0``"0$5)'^1""
M.I$@`A_6T```D!%61_D0HCJ1(`(?UM```)`16D?Y$,(ZD2`"'];0``"0$5Y'
M^1#B.I$@`A_6T```D!%B1_D0`CN1(`(?UM```)`19D?Y$"([D2`"'];0``"0
M$6I'^1!".Y$@`A_6T```D!%N1_D08CN1(`(?UM```)`1<D?Y$(([D2`"'];0
M``"0$79'^1"B.Y$@`A_6T```D!%Z1_D0PCN1(`(?UM```)`1?D?Y$.([D2`"
M']:P``#P$8)'^1`"/)$@`A_6L```\!&&1_D0(CR1(`(?UK```/`1BD?Y$$(\
MD2`"']:P``#P$8Y'^1!B/)$@`A_6L```\!&21_D0@CR1(`(?UK```/`1ED?Y
M$*(\D2`"']:P``#P$9I'^1#"/)$@`A_6L```\!&>1_D0XCR1(`(?UK```/`1
MHD?Y$`(]D2`"']:P``#P$:9'^1`B/9$@`A_6L```\!&J1_D00CV1(`(?UK``
M`/`1KD?Y$&(]D2`"']:P``#P$;)'^1""/9$@`A_6L```\!&V1_D0HCV1(`(?
MUOU[N:G]`P"1\U,!J;,``/"T``#P8]Y'^:*'!*FB(P&19`!`^:0W`/D$`(#2
MH%\`N:%#`9&@<P&1BO__EZ```/"B``#P`/1'^4+L1_GA`P*J?@P`E*```/``
MU$?Y``!`.6`!`#5+__^7P@``D$!0`/E`#@"TM```\!;__Y>`TD?Y``!`N4__
M_Y<?A"0YE-)'^8`"0+E+__^7`>A3.2$`'S(!Z!,Y@`)`N4;__Y<"Z%,YH5]`
MN0,`_))"```R`N@3.2$4`!&U6P*IMQL`^2%\0),_``/K:`H`5"#P?=,U__^7
MI2M`^<(``)#4``"0A"("D4<\0/D#``#PJ`!`^0$``/!C@!Z1(:`>D88`@%*B
M7T"Y"`P`J0<$`:E?!`!QA@0`N8`$`/E-`0!4(0"`TN8`@)(D$``1HWAA^"$$
M`)'$S"2+7P`!:P-H)/A,__]411``$98B`I'C`P"J`0``L`7,)8L$`(#2P`Y`
M^4(,`!$A8#*1OX`?^&___Y?U`P`JH`,`-)8B`I&WDP&1P`Y`^>G^_Y<```#P
MX0,7J@`@%)&K!`"4``(`M)0B`I&`#D#YS?[_EU3__Y=SWD?YX`,5*J(W0/EA
M`D#Y00`!RF$#`+6U6T*I\U-!J;<;0/G]>\>HP`-?UL`*0/G@``"T^`L`E.[_
M_Q?`#D#Y;___E_4#`"KA__\7````\.$#%ZH`0!*1CP0`E,`*`/F`_/^T[`L`
ME.+__Q>A``#P````\`!@'I$AY$?Y)/__E_/^_Y>U6P*I(`"`4K<;`/F#_O^7
M'0"`TAX`@-+E`P"JX0-`^>(C`)'F`P"1H```\`#P1_FC``#P8^A'^:0``/"$
MO$?YNO[_E_'^_Y>@``#P`-A'^4```+3I_O\7P`-?U@````#```"0```"D<$`
M`)`A``*1/P``ZZ```%2A``#P(<!'^4$``+0@`!_6P`-?UA\@`]7```"0```"
MD<$``)`A``*1(0``RR'\0Y,A_$&+(?Q!DZ$``+2B``#P0OQ'^4(``+1``!_6
MP`-?UOU[OJG]`P"1\PL`^=,``)!@`D(Y0`$`-:```/``Q$?Y@```M,```)``
M!$#Y5?[_E]K__Y<@`(!28`(".?,+0/G]>\*HP`-?UN#__Q<`````_X,*T:@`
M`/`$X`"1">`!D?U[`*G]`P"1HF,`D0'=1_E'(`"1(P!`^:-/`?D#`(#2@0!`
MN8.$0/@A",!:X8`?^)\`">MA_&#39OQHT\8<>)(EW'C3(1P(4Z4<<)+#X$.J
M(0`%JB$``ZKA!`'X(?[_5$8`")$?(`/510!`^4(@`)%#!$#Y1!Q`^4$P0/EC
M``7*7P`&ZR$`!,HA``/*(_Q?TV$$`:HA?$"203P`^6'^_U0%$$"I@`!GG@8<
M0:GA`&>>P@!GGH'\0M,A>`2JHOQ;TT`<82XM?$"2H0%GGD(4!:JKOT&I(S./
MT@P`9IZ@`&>>0U"K\@D00/D@'&(N:P$#BZ[\0M/O`0.+@D$BB\YY!:I"``N+
M(0`.R@H`9IY"``D+JQ=`^2$``HI,_%O3(0`-RHP5`JHA``:+2@$'B]!]0))*
M`0^+C`$*"TK\0M-">0*J:@$#BXO]6],A``J+:Q4,JLH!`LJ._4+3:P$!"TH!
M#(K,>0RJH3M#J4H!$,I*`0V+;?U;TR$``XNM%0NJ2@$!BT$`#,JJ`0H+3WQ`
MDB$`"XIB_4+3(0`/RDMX"ZK.`0.+(0`0BTW]6]."`0O*K14*JB$`#HNA`0$+
MD'U`DJXC0/E"``J*3?U"TT(`$,JM>0JJ0@`/B\H!`XLN_%O3SA4!JD(`"HMJ
M`0W*P@$""V]]0)*N)T#Y2@$!BBS\0M-*`0_*C'D!JDH!$(O!`0.+3OQ;TTH!
M`8O.%0*JH0$,RLH!"@NM?4"2KBM`^2$``HI+_$+3(0`-RFMY`JHA``^+P@$#
MBT[]6]/.%0JJ(0`"BX(!"\K!`0$+CWU`DJXO0/E"``J*3/U"TT(`#\J,>0JJ
M0@`-B\H!`XLM_%O30@`*BZT5`:IJ`0S*H@$""VY]0)*M,T#Y2@$!BBO\0M-*
M`0[*:WD!JDH!#XNA`0.+3?Q;TZT5`JI*`0&+@0$+RJH!"@N/?4"2K3=`^2$`
M`HI,_$+3(0`/RHQY`JHA``Z+H@$#BTW]6],A``*+K14*JF(!#,JA`0$+;GU`
MDJT[0/E"``J*2_U"TT(`#LIK>0JJ0@`/BZH!`XLM_%O3K14!JD(`"HN*`0O*
MH@$""X]]0)*M/T#Y2@$!BBS\0M-*`0_*C'D!JDH!#HNA`0.+3?Q;TTH!`8NM
M%0*J80$,RJH!"@MN?4"2K4-`^2$``HI+_$+3(0`.RFMY`JHA``^+H@$#BX]]
M0)(A``*+@@$+RDW]6]-"``J*K14*JD(`#\JA`0$+0@`.BZV[2*E,_4+3C'D*
MJG%]0)*J`0.++?Q;TZT5`:I"``J+:@$,RJ(!`@M*`0&*+?Q"TTH!$<JM>0&J
M2@$/B\$!`XM+_%O32@$!BVL5`JJ!`0W*:P$*"Y!]0)*JNTFI(0`"BB$`$,I/
M_$+3[WD"JDH!`XLA`!&+;/U;TR$`"HN,%0NJJ@$/RHP!`0NQ?4"22@$+BDH!
M$<J-_5O3S@$#BTH!$(MA_4+32@$.BR%X"ZJK%0RJ:P$*"^(!`<KP?4"20@`,
MBJU70/E"`!#*:OU;TT(`$8NM`0.+2A4+JD(`#8N-_4+3K7D,JDI`*HM.?4"2
M+WQ`DB$`#<JL6T#Y(0`+BL+]6],A``_*0A0.JH,!`XLA`!"+(0`#BV/]0M,R
M0"*+87@+JJ,!`<I0?D"28P`*2BITG=)C``^+`OY;TZR_2ZDJVZWR0A00JLO]
M0M.,`0J+:WD.JF,`#(MQ0"*+(@`+RBY^0))"`!)*0D`MB^T!"HO,_5O30@`-
MBXP5#JH#_D+38W@0JDQ`+(MB`0/*K<-,J8]]0))"`!%*04`ABZ(!"HOM_5O3
M(0`"BZT5#ZK"_4+30G@.JBU`+8MA``+*KGU`DBP`#$J+02N+`0(*B\S]6]-K
M`0&+C!4.JN']0M,A>`^JL&]`^6Q!+(M+``'*CWU`DFT!#4JC02.+"P(*B^W]
M6]-C``N+K14/JLO]0M-K>0ZJL'-`^6U`+8LC``O*KGU`DFP`#$J"02*+`P(*
MB\S]6]-"``.+C!4.JN/]0M-C>`^JL'=`^4Q`+(MB`0/*CWU`DDT`#4JA02&+
M`@(*B^W]6],A``*+K14/JL+]0M-">`ZJL'M`^2U`+8MA``+*KGU`DBP`#$J+
M02N+`0(*B\S]6]-K`0&+C!4.JN']0M,A>`^JL']`^6Q!+(M+``'*CWU`DFT!
M#4JC02.+"P(*B^W]6]-C``N+K14/JLO]0M-K>0ZJL(-`^6U`+8LC``O*KGU`
MDFP`#$J"02*+`P(*B\S]6]-"``.+C!4.JN/]0M-C>`^JL(=`^4Q`+(MB`0/*
MCWU`DDT`#4JA02&+`@(*B^W]6],A``*+K14/JL+]0M-">`ZJL(M`^2U`+8MA
M``+*KGU`DBP`#$J+02N+`0(*B\S]6]-K`0&+C!4.JN']0M,A>`^JL(]`^6Q!
M+(M+``'*CWU`DFT!#4JC02.+"P(*B^W]6]-C``N+K14/JLO]0M-K>0ZJL)-`
M^6U`+8LC``O*KGU`DFP`#$J"02*+`P(*B\S]6]-"``.+C!4.JN/]0M-C>`^J
ML)=`^4Q`+(MB`0/*CWU`DDT`#4JA02&+`@(*B^W]6],A``*+K14/JL+]0M-"
M>`ZJL)M`^2U`+8MA``+*KGU`DBP`#$J+02N+`0(*B\S]6]-K`0&+C!4.JN']
M0M,A>`^JL)]`^6M!+(M,``'*;WU`DHT!#4JC02.+#`(*B^W]6]-C``R+K14/
MJLS]0M.,>0ZJL*-`^6U`+8LC``S*KGU`DFL`"TIB02*+`P(*B\O]6]-"``.+
M:Q4.JN/]0M-O>`^J0D`KBX,!#\I+?$"28P`-2F%`(8O#_4+3;?U;TV-X#JJN
M%0NJ<7Q`DK"W5*D0`@J+J@$*BR$`$(O!`0$+[@$#RLX!`DIB_4+30G@+JLQ!
M+(LN_%O337Q`DHH!"HMC``*JS!4!JF,``8JNPU6IC`$*"RH"#8HK_$+38P`*
MJHJ;E])JX['R87D!JLX!"HMC0"^+B_U;TR]\0))C``Z+:Q4,JD(``:IK`0,+
M0@`,BJ,!#XI"``.J@_U"TV-X#*H0`@J+0@`1BVS]6]-N?$"20@`0BXP5"ZHA
M``.JC`$""R$`"XKB`0Z*L+=`^2$``JIB_4+30G@+JA`""HLA``V+B_U;TTU\
M0)(A`!"+:Q4,JF,``JIK`0$+8P`,BL$!#8JPNT#Y8P`!JH']0M,A>`RJ$`(*
MBV,`#XML_5O3+WQ`DF,`$(N,%0NJ0@`!JHP!`PM"``N*HP$/BK"_0/E"``.J
M8_U"TV-X"ZH0`@J+0@`.BXO]6]-N?$"20@`0BVL5#*HA``.J:P$""R$`#(KB
M`0Z*L,-`^2$``JJ"_4+30G@,JA`""HLA``V+;/U;TTU\0)(A`!"+C!4+JF,`
M`JJ,`0$+8P`+BL$!#8JPQT#Y8P`!JF']0M,A>`NJ$`(*BV,`#XN+_5O3+WQ`
MDF,`$(MK%0RJ0@`!JFL!`PM"``R*HP$/BK#+0/E"``.J@_U"TV-X#*H0`@J+
M0@`.BVS]6]-N?$"20@`0BXP5"ZHA``.JC`$""R$`"XKB`0Z*L,]`^2$``JIB
M_4+30G@+JA`""HLA``V+B_U;TTU\0)(A`!"+:Q4,JF,``JIK`0$+8P`,BL$!
M#8JPTT#Y8P`!JH']0M,A>`RJ$`(*BV,`#XML_5O3+WQ`DF,`$(N,%0NJ0@`!
MJHP!`PM"``N*HP$/BK#70/E"``.J8_U"TV-X"ZH0`@J+0@`.BXO]6]-N?$"2
M0@`0BVL5#*HA``.J:P$""R$`#(KB`0Z*L-M`^2$``JJ"_4+30G@,JA`""HLA
M``V+;/U;TTU\0)(A`!"+C!4+JF,``JJ,`0$+8P`+BL$!#8JPWT#Y8P`!JF']
M0M,A>`NJ$`(*BV,`#XN+_5O3+WQ`DF,`$(MK%0RJ0@`!JFL!`PM"``R*HP$/
MBK#C0/E"``.J@_U"TV-X#*H0`@J+0@`.BVS]6]-N?$"20@`0BXP5"ZHA``.J
MC`$""R$`"XKB`0Z*L.=`^2$``JIB_4+30G@+JA`""HLA``V+B_U;TTU\0)(A
M`!"+:Q4,JF,``JIK`0$+8P`,BL$!#8JPZT#Y8P`!JH']0M,A>`RJ$`(*BV,`
M#XMO_5O3+'Q`DF,`$(OO%0NJ0@`!JN\!`PM"``N*HP$,BK#O0/E"``.J8_U"
MTV-X"ZH0`@J+0@`.B^[]6]-K?$"20@`0B\X5#ZHA``.JS@$""Y`!"XHA``^*
MHO-`^2$`$*KP_4+30@`*BR$`#8O-_5O3(0`"BZT5#JH">@^JK0$!"T]\0))C
M``*J80$/BF,`#HJP]T#Y8P`!JJ']6],0`@J+8P`,BRP4#:IC`!"+P?U"T[#[
M0/DA>`ZJ<D`LBT-^0)(L?$"20@`!JO$!#(I"``V*;OQ;TT(`$:H0`@J+0@`+
MB\H5`ZI"`!"+J_U"TU%`*HMM>0VJ,'Y`DB$`#<JJ_T#Y(0`22@[^6]/".IC2
M0DRY\LX5$*I*`0*+(0`/BR$`"HMJ_$+3,D`NBT-Y`ZI.?D"2JP-!^:H!`\H(
MW4?Y80$"BTH!$4K+_5O32@$,BVL5#JI*`0&+`?Y"TZP'0?E102N+*G@0JB]^
M0))A``K*(0`22HP!`HOK_5O3(4`MBVL5#ZHA``R+S?U"TZP+0?DP0"N+H7D.
MJ@Y^0))-`0'*K0$12HP!`HO+_5O3HT$CBVL5#JIC``R+[?U"TZP/0?EQ0"N+
MHWD/JB]^0)(M``/*K0$02HP!`HOK_5O3JD$JBVL5#ZI*`0R+S?U"TZP30?E0
M02N+JGD.J@Y^0))M``K*K0$12HP!`HO+_5O3H4$ABVL5#JHA``R+[?U"TZP7
M0?DQ0"N+H7D/JB]^0))-`0'*K0$02HP!`HOK_5O3HT$CBVL5#ZIC``R+S?U"
MTZP;0?EP0"N+HWD.J@Y^0)(M``/*K0$12HP!`HO+_5O3JD$JBVL5#JI*`0R+
M[?U"TZP?0?E102N+JGD/JB]^0))M``K*K0$02HP!`HOK_5O3H4$ABVL5#ZHA
M``R+S?U"TZPC0?DP0"N+H7D.J@Y^0))-`0'*K0$12HP!`HO+_5O3HT$CBVL5
M#JIC``R+[?U"TZPG0?EQ0"N+HWD/JB]^0)(M``/*K0$02HP!`HOK_5O3JD$J
MBVL5#ZI*`0R+S?U"TZPK0?E002N+JGD.J@Y^0))M``K*K0$12HP!`HO+_5O3
MH4$ABVL5#JHA``R+[?U"TZPO0?DQ0"N+H7D/JB]^0))-`0'*K0$02HP!`HOK
M_5O3HT$CBVL5#ZIC``R+S?U"TZPS0?EP0"N+HWD.J@Y^0)(M``/*K0$12HP!
M`HO+_5O3JD$JBVL5#JI*`0R+[?U"TZPW0?E102N+JGD/JB]^0))M``K*K0$0
M2HP!`HOK_5O3H4$ABVL5#ZHA``R+S/U"TZT[0?DP0"N+@7D.J@M^0)).`0'*
MS@$12JT!`HML_5O3PT$CBXP5"ZIC``V+[OU"TZT_0?EQ0"R+PWD/JBQ^0)(O
M``/*[P$02JT!`HN._5O3ZD$JB\X5#*I*`0V+;_U"TZU#0?E002Z+ZWD+J@]^
M0))N``O*S@$12JT!`HOJ_5O3P4$ABTH5#ZHA``V+C?U"TZY'0?FL>0RJ(4`J
MBRU\0))J`0S*2@$02LX!`HM#02.+\/U"TZK]6]-C``Z+#WH/JDH5#:I*`0,+
MKDM!^8,!#\J$``H+80`!2L(!`HLK0"N+0_U;TVL!`HNA_4+38A0*JB%X#:I"
M``L+)@`&"^<!!PN)`0D+10`%"P40`*D&'`&I"1``^:%/0?D``4#Y(```RH``
M`+7]>T"I_X,*D<`#7]9O^O^7_7N\J?T#`)'S"P#Y@`<`M*(``-"X'P#Y0OA'
M^5@`0/DX!P"TM1,`^14`@%("`$`Y7_0`<4080'IA`P!4$P-`^9,%`+2T#P#Y
MM7Y`D[;?`JGT`QBJ]P,!JO8#`*H?(`/5X`,3JN(#%:KA`Q:J)_K_EX```#5@
M:G4X'_0`<2`"`%23CD#X\_[_M;370:FVWT*IN!]`^>`#$ZKS"T#Y_7O$J,`#
M7];U`P"JHAY`.%_T`'%$&$!ZH?__5+4"`$O@__\7E`(8R[4&`)%S`A6+E/Y#
MD_0"`+G@`Q.JM-=!J;;?0JFX'T#Y\PM`^?U[Q*C``U_6M1-`^;@?0/GG__\7
M$P"`TN7__Q<3`(#2N!]`^>+__Q?]>[RI_0,`D?5;`JFV``#0\U,!J;,``-#U
M`P"JP-Y'^7/Z1_FTTP"1`0!`^:$?`/D!`(#2X0,4JN`#%:JM__^7``(`M*,W
M@+EB`D#Y0`P#BP$$0/E!>"/XX?[_M!\@`]4`(`"1`01`^0$``/FA__^UX0,4
MJN`#%:J>__^70/[_M=;>1_FA'T#YP`)`^2```,J@``"U\U-!J?5;0JG]>\2H
MP`-?U@'Z_Y?]>[FI_0,`D?-3`:GS`P&J]5L"J;4``-#W8P.I]`,`JJ'>1_E@
M`D`Y(@!`^:(W`/D"`(#2'_0`<7,6DYK@`Q.J?/G_E_8#`*JADP&1X`,4JG[_
M_Y<`"`"T]P,`JG7Y_Y<?`!;KH@8`5+AG@+FW``#0&/-]TX`"0#D?]`!Q!!A`
M>H`,`%3A`Q2J(!Q`.!_T`'$$&$!ZH?__5"$`%,LA?$"3]_I'^<`*`)$```&+
M]@)`^9CY_Y?`:CCXH`L`M*-G@+F`!@"1X@)`^8$"0#E">&/X/_0`<2080'I!
M```YP```5`$40#A!'``X/_0`<2080'J!__]4000`D:`'@%)````Y8!9`."`4
M`#C`__\U``"`4K7>1_FB-T#YH0)`^4$``<JA"`"U\U-!J?5;0JGW8T.I_7O'
MJ,`#7]8``(#2'R`#U6%J8#CA:B`X``0`D:'__S7O__\7MP``T+EK!*F[*P#Y
MX/I'^1@`0/D``T#Y8`4`M.$#&*H``(!2`@``%.`#&2HBC$#X&00`$:+__[4`
M#``1`'Q]DZ$``/`BB$"Y8@(`-2(`@%(BB`"Y6OG_E_L#`*J@`P"T.G]`D^$#
M&*I8\WW3X@,8JA/Y_Y?@^D?Y&P``^5H'`)%_>SKXN6<`N;EK1*F[*T#YI/__
M%^$#`*K@`QBJ>/G_E_L#`*K@^D?Y&P``^3L!`+0Z?T"36/-]T_'__Q<!`(#2
MH___%P`"@-(9`(!2W?__%[EK1*F[*T#Y``"`$KC__Q>Y:P2INRL`^7'Y_Y?]
M>[*I_0,`D?,+`/FS``#08=Y'^2(`0/FB;P#Y`@"`TL```+2T#P#Y]`,`J@$`
M0#E!`0`UM`]`^7/>1_FA;T#Y8`)`^2```,J@"0"U\PM`^?U[SJC``U_6MA<`
M^0'Y_Y?V`P"JX`8`M+=C`ZD7``#0&```T+HG`/GW8A"1&(,0D;IC`9&U$P#Y
MX`,6JI'Y_Y?@!0"T%4P`D>$#%ZK@`Q6J:/G_ER#__S3A`QBJX`,5JF3Y_Y>@
M_O\TN2,`^>`#%*K,^/^7^0,`JN`#%:K)^/^7```9"P`(`!$`?$"3_?C_E^4#
M%:KD`Q2J`P``T&.@$)'Y`P"J`@"`DB$`@%+!^/^7X@,:JN$#&:H``(!2Q?C_
MEQ\$`#&@``!4H&M`N0`,%!(?$$!Q8`(`5.`#&:J=^?^7X`,9JE_Y_Y>Y(T#Y
MT___%[0/0/FV%T#YO/__%^`#%JH8^?^7X`,4JD+Y_Y>TUT&IMM]"J;@?0/FZ
M)T#YL___%^`#&:JC__^7[O__%[37`:FVWP*IN.<#J;HG`/D-^?^7_7N^J?T#
M`)'S4P&ILP``T/0#`*ISTD?Y8`)`N?7X_Y<"``B1X0,4J@``@%(Y^?^7H```
M-```@%+S4T&I_7O"J,`#7]9@`D"YZOC_EP`00KD`#!02'Q!`<>```%1@`D"Y
MY/C_EP`00KD`#!02'RA`<2'^_U1!`(!2X`,4J@'Y_Y<?``!QX!>?&O-30:G]
M>\*HP`-?UA\@`]40"H+2_V,PR^+_@=+]>P"I_0,`D?,+`/FS``#0]5L"J;4C
M`9'W8P.I]@,`JF/>1_GW`P&J````T.$#%:ID`$#YI"<(^00`@-(`P!"1;_C_
MEQ\``'%-!0!4`@0`4;0/`/FA``#0H\IB."'01_DX`$"Y8P,`-.(#`"I4?$"3
MX06`4N(#%*K@`Q6J)/G_EZ`"`+3@`Q@JL?C_E^,#%*KB`Q6JX0,6JB7Y_Y>T
M#T#Y<]Y'^:$G2/E@`D#Y(```RH`"`+7]>T"I$`J"TO,+0/GU6T*I]V-#J?]C
M,(O``U_6XOS_-;0/0/G@`Q@JG/C_E^(#%ZKA`Q:J>?C_E^W__Q>@``#0`-!'
M^1@`0+GW__\7M`\`^:+X_Y<?(`/5_7N_J:```-#]`P"1`-!'^0``0+F+^/^7
MH@``T`,``-#]>\&H`0``T$+,1_EC@`^1(0`1D<?X_Q?]>[ZI_0,`D?,+`/FS
M``#0<])'^6`"0+E\^/^7Z___EV`"0+EY^/^7\PM`^?U[PJ@$``#0A$`>D0(`
M`+`!``#0!0"`4N,#!*I"`#J1(8`1D<[X_Q<?(`/5$`J$TO]C,,L`"(+2_7L`
MJ?T#`)'S4P&IM```T/5;`JFV`P"+@-Y'^;/C`)$!`$#YH2<0^0$`@-(N^/^7
MY`,`*@4``-`#``#0I>`1D6,`$I$B`(+2(0"`4N`#$ZKU]_^7`@""TN$#%JK@
M`Q.J_??_EP`#^#?S`P"J``0`$0!\0),@^/^7]0,`JL```+1S?D"3X0,6JN(#
M$ZK6]_^7OVHS.)3>1_G@`Q6JHB=0^8$"0/E!``'*(0$`M?U[0*D0"H32\U-!
MJ?5;0JG_8S"+P`-?UA4`@-+S__\71OC_EQ\@`]7(__\7'R`#U1`.@M+_8S#+
M_7L`J?T#`)'W&P#YMP``T/-3`:GT`P"J]1,`^?,#`:KBWD?YH9,!D0```-``
M0!*10P!`^:,W"/D#`(#2P_W_E_4#`*KA!8!2X`,4JH'X_Y=``@"T````T.$#
M%*H`@!*1*/[_E^`#%*KWWD?YHC=(^>$"0/E!``'*P0T`M?U[0*D0#H+2\U-!
MJ?430/GW&T#Y_V,PB\`#7]:X'P#YX`,4JKHG`/FC]_^7&```T/H#`"H!PQ*1
MX`,3JIKW_Y?S`P"J(`L`M+87`/FVHP&1N2,`^1D``-"[*P#Y.>,2D1L``-![
M8Q"1'R`#U6`"0#D`!P`TM0``M.$#$ZK@`Q6J(?C_ET`%`#3@`Q.JBO?_E^$#
M`"I@PB"+`/!?.!^\`''A``!4(00`46#"(8M_RB$X`/!?.!^\`'%@__]40`<`
M$0$``0L__#]QS`,`5.0#$ZJS``#0`@""TB$`@%+F`Q2JY0,9J@,``-#@`Q:J
M8P`3D77W_Y=STD?Y8`)`N=+W_Y<"``B1X0,6J@``@%)V]_^7X```-6`"0+G+
M]_^7`!!"N0`,%!(?($!Q0`(`5`'#$I$``(#27/?_E_,#`*J`^?^UMA=`^;CG
M0ZFZ[T2IH___%[4``+3A`QNJX`,5JNKW_Y=@_O\T\P,;JB$`@%+4__\7(0"`
M4N`#%JK7]_^7@/W_->$#%JH```#0`(`2D;[]_Y?@`Q:JM/?_E[870/FXYT.I
MNN]$J9+__Q>X'T#YNB=`^8K__Q>V%P#YN.<#J;KO!*FQ]_^7`0!`.>(#`*KA
M```T'R`#U0`$`)$_O`!Q0A"`F@$`0#F!__\UX`,"JL`#7]8?(`/50`@`M/U[
MOJG]`P"1\U,!J?,#`*H4`$`Y]`(`-"GW_Y<`!`#18@(`BW\"`NNB`P!48&I@
M.!^\`'&@``!4%@``%$``0#D?O`!Q80(`5$($`-%_`@+K8?__5)^^`''```!4
M\U-!J0```+#]>\*H`.`2D8#W_Q?S4T&I````L/U[PJ@`8!"1>_?_%T``0#D?
MO`!QH`$`5$($`-%_`@+K8___5'\"`NN@_?]40@0`T7\"`NL"`0!4'R`#U4``
M0#D?O`!Q@0``5$($`-%_`@+K8___5$(`$\M`"`"1'P1`\<@!`%2D``#0A*`"
MD0,`@M)"!`"1X0,3JN`#!*HN]_^7\U-!J?U[PJC``U_6````L`!@$)%8]_\7
M``"`TOG__Q<?(`/5_7NXJ0$``+`A@`^1````L/T#`)'S4P&ILP``L/5;`JD`
M(!.18]Y'^18``+#W8P.I%P``L"8<0:EB`$#YHC\`^0(`@-(D%$*IIA\%J2%@
M0'D8``"PI!<&J10``+"AXP!YE*(4D;4S`9$8_?^7````L`!@$Y$5_?^7````
ML`"`$Y$2_?^7````L`#`$Y$/_?^7P.(3D0W]_Y<```"P`"`4D0K]_Y?@0A*1
M"/W_EP!C%)$&_?^7X`,4J@3]_Y<```"P`.`4D0']_Y<```"P`(`2D?[\_Y<`
M``"PX0,5J@`@%9&V_/^7@```M.$#`*K@`Q2J(/W_EP```+#A`Q6J`(`5D:[\
M_Y>@``"T`@``L.$#`*I`X!61%_W_EP```+#A`Q6J`"`6D:7\_Y=``@"TX0,`
MJN!"$I$/_?^7`0``L,#B$Y$A`!>1"_W_EW/>1_FA/T#Y8`)`^2```,I``P"U
M\U-!J?5;0JGW8T.I_7O(J,`#7]8```"PX0,5J@!@%I&/_/^7@`$`M0$``+"T
M0P&10@&`TB'`%I&@AP&1RO;_E^#\_S6!;@"1`&,4D?+\_Y?C__\7X0,`J@!C
M%)'N_/^7W___%^SV_Y<?(`/5_7N]J?T#`)'S4P&ILP``L+0``-!AWD?Y@!)`
MN2(`0/FB%P#Y`@"`TA\$`#$@`0!4<]Y'^:(70/EA`D#Y00`!RB$"`+7S4T&I
M_7O#J,`#7]:ADP"1````L`!@%)%E_/^7X0,`J@``@%*A``"T(`!`.1_``'$$
M&$!ZX`>?&H`2`+GL__\7R?;_E_U[OZG]`P"1:O;_E^GV_Y>```"T``!`^?U[
MP:C``U_6``"`TOW__Q?]>[NI_0,`D?,+`/FS``"P]5L"J14``+#W&P#YMR(7
MD6+>1_GV`P"JH1,!D>`#%ZI#`$#YHR<`^0,`@-)!_/^78`$`M+0/`/GT`P"J
M`0!`.<$``#3A`Q:J&/?_ER`"`+2T#T#Y!0``%+0/0/GA`Q:JH"(7D:'\_Y=S
MWD?YH2=`^6`"0/D@``#*H`,`M?,+0/GU6T*I]QM`^?U[Q:C``U_6X`,6JB'V
M_Y?U`P"JX`,4JA[V_Y>@`@"+``@`D5/V_Y?F`Q2JY`,6J@4``+`#``"PI<`2
MD6,`$Y$"`("2]0,`JB$`@%(5]O^7X0,5JN`#%ZJ"_/^7M`]`^>#__Q>T#P#Y
M?O;_EQ\@`]40.I#2_V,PRZH``-!*00"1"P20TOU[`:G]0P"1K0,+BT250*GU
M6P.IM@``L/,3`/GW(P#Y]P,`JOHO`/FU,P*1S-Y'^1H``+!+#4#Y0`5"J8X!
M0/FNS0#Y#@"`TD8=0ZFD%PFI2"5$J:M3`/E"#46IHH\*J4HQ0/FJ7P#YH`<,
MJ>$#%:JF'PVI0$,2D:@G#JGJ^_^7@```M`$`0#GS`P"JX1(`-;0/`/FXYP.I
MNRL`^8C__Y?T`P"JP!(`M.`#%*K8]?^7`/A_TP`$`)$-]O^7A`)`.?D#`*J$
M`0`T````L/,#&:H8@!>1X`,3JN,#&*H"`("2(0"`4L[U_Y=S"@"1A!Y`."3_
M_S6@8T#Y8`L`M+@#`Y$S`(#2!0``%',&`)$`#Q.+`(!?^(`*`+3A`Q6JPOO_
ME_0#`*H@__^T`0!`.>'^_S0?_?^7H/[_-.`#%*H@]O^7^P,`J@`)`+0?(`/5
MX`,;JJ_U_Y?S`P"JX`,9JJSU_Y<3`!,+<Q(0$1@``+!S?D"3X`,3JM[U_Y?G
M`QFJ!>,2D>0#&ZH&``"P`P``L,:@%Y%CP!>1`@"`DO0#`*HA`(!2G_7_EP$X
M@%+@`Q2JB/;_EQ\$`#&A``!4??;_EP4`0+F_1`!QH0P`5+L``+![TT?Y8`-`
MN?+U_Y<"``B1X0,4J@``@%(V]O^7^0,`*@`&`#2@``"PXP)`^>0#%*H"``"P
M`,A'^4(@&9$A`(!2$P"`T@``0/D.]O^7M`]`^;CG0ZF[*T#YUMY'^0$$D-*A
M`P&+X`,3JB+,0/G!`D#Y00`!RF$Y`+7]>T&I$#J0TO,30/GU6T.I]R-`^?HO
M0/G_8S"+P`-?UKA#`I$4`(!2$]MT^+,!`+1@`D`Y8`$`-.`#$ZJ4!@`1ROS_
MER#__S3@`Q.JR_7_E_L#`*J@]?^U$]MT^+/^_[4;`(#2J?__%V`#0+F[]?^7
M`!!"N0`,%!(?$$!Q@?G_5+PO`/E@`T"YM/7_EQP80KEF]?^7GP,`:Z`%`%2\
M+T#YP___%__^_Y?@`Q.JL_7_E_,#`*K+__\7N*,"D1,`@%(`VW/XH`$`M.$#
M%:IS!@`11/O_EV#__[0!`$`Y(?__-*;U_Y?T`P"JX.O_M0#;<_C`_O^U'R`#
MU:`!@-)K]?^7%```L/D#`*ID"H!2E&(7D5W__Q>@``"PXP)`^>0#%*H"``"P
M`,A'^4(`&)$A`(!2$P"`T@``0/FT]?^7M`]`^;CG0ZF[*T#YIO__%V`#0+F"
M]?^7`!!"N0`@`!(?``=QX?G_5.`#$ZI0]?^7X0,5JO,#`*H```"P```9D1G[
M_Y<@"P"T]0)`^7SU_Y?A`P"JX`,5JC_]_Y?U`P"J0`H`M.`#%:H)]?^7^P,`
MJA\,`'$-`@!4`'Q`DP$``+``$`#1(8`:D:`"`(N4]?^7(`$`-7\3`'&@(P!4
M8!,`4:#"((L`\%\X'[P`<0`C`%0?(`/5@/[_E\```#4!`(!2X`,5JLKU_Y>@
M=P"Y(`<`-0$``+`A`!>1````L`!@%)%?^_^7&.,2D1WU_Y<5``"PM4(>D>8#
M`"H#``"PYP,5JN4#&*KD`Q2J8P`;D0(`@)(A`(!2X`,3JA<``+#@]/^7]T(;
MD1$``!3!]?^7``!`N1]$`'%!`@!4"?7_E_4#`/DY!P`1Y@,`*N<#&2KE`QBJ
MY`,4JN,#%ZH"`("2(0"`4N`#$ZK.]/^7`3B`4N`#$ZJW]?^7'P0`,8#]_U3@
M`Q2J<_7_E^$#$ZI`0Q*1-/O_E^`#$ZIT_O^7M`]`^;CG0ZF[<T6I0/__%_4"
M0/FN__\7H^,&D4(`@%+U`P.J(0*`DJ,_`/D.]?^7H'=`N<(`@-+A`Q6J?O7_
MEZ#C1CF````UH.=&.1\,`7'`'`!4H'=`N0(`@%(!`(#2N<,#D;RC!)'_]/^7
MO_\1J2#C`)$D8(32(W&5TL*?F]+!CHK2H#<`^0`^G-*DZ*SRH_F]\D(7L_)!
M!J+R0'JX\J0/#ZFB!Q"IH(L`^;]K`;F@=T"Y`@"0TJ$_0/E>]?^7XP,`JO4#
M`"H?``!QK0@`5*6+4:EA?$"3H&M!N:0,`0N_``3K0I2"FD%T08NDAQ&IX!,`
M-`$(@%(U``!+?P`5:Z$_0/EUT)4:HC=`^:,S`/F[?D"30,`@B^(#&ZIJ]/^7
MH&M!N:,S0/F@`@`+H&L!N1\``7'A^_]4H#]`^74`%4L;`!N+X`,9JC/V_Y>_
M_@!QS0(`5+4"`5&@?@93H&,`N1=D&E/W`@&1=P,7BV070*F$%P"I8@]!J8(/
M`:E@!T*I@`<"J68?0ZF&'P.I>P,!D>`#&:H@]O^7_P(;ZX'^_U2@8T"YM1H`
M2Z`W0/D#"8#2HGY`D^$#&ZI_]/^7M6L!N:!W0+D"`)#2H3]`^1KU_Y?C`P"J
M]0,`*A\``'&L]_]4H'=`N;ST_Y>UWU&IX@^`$J$B`U,@!``1'^``<8++(3AL
M#0!4(^,`D0('@%)"``!+`0"`4F#`((M"?$"3AO3_E^'^6-/@_E#3H8,%.:'^
M6-.@AP4YX/Y(TZ"+!3F@_E#3H)<%.:#^2-.WCP4YO",&D:&3!3F;HP"1H)L%
M.>`#&:JUGP4Y[/7_EZ873ZD```"PHPM0J1>`%Y&ABT#YR/Q0T\?\2-.@_%C3
MJ?Q0TZC'!3FGRP4YJ/Q(TV?\6-.@TP4Y8/Q(T\1\&%.FSP4Y:OQ0TZ3#!3DF
M_%C3J=<%.?4#'*JHVP4Y2?Q8TTC\4-.EWP4YI^,%.27\4--'_$C3JN<%.:#K
M!3FYQP61(/Q(TZ/O!3FI\P4YJ/<%.:?[!3FB_P4YI@,&.:4'!CF@"P8YH0\&
M.0(``!0D%T`XX`,5JN,#%ZH"`("2(0"`4K4*`)'V\_^7?P,5ZP'__U0'``"P
MY@,<JN=`'I$#``"PO\,&.07C$I'D`Q2J8\`:D0(`@)(A`(!2X`,3JNCS_Y<?
M__\7NS]`^7?__Q?W!D#Y-]W_M.`#%ZK=\_^7'PP`\:G<_U0`$`#1`0``L.`"
M`(LAH!J1:O3_EQ\``'&U$I>:W?[_%P((@%)"``!+`0"`4COC`)%"?$"38,,@
MBQST_Y?@`QFJDO7_EZ"#")$?_#"I/_\$J3__!:D_-P#YC___%Z#K1CD?!`%Q
M(>/_5*#O1CD?#`%QP>+_5*#S1CD?(`%Q8>+_5*#W1CD?%`%Q`>+_5+=W0+E"
M`(!2(0>`DN`#%RH/]/^7M3]`^2(%@-+@`Q<JX0,5JG[T_Y<'``"PY@,5J@,`
M`+#G0!Z1O___%[0/`/FXYP.INW,%J1GT_Y?]>[BIH```L/T#`)'W&P#YMP``
ML/-3`:GSTD?Y]5L"J;73`9'Z)P#Y`-Q'^;4S`/D!`$#YH3\`^0$`@-)@`D"Y
M^//_E_0#`*I@`D"Y]?/_EX'B0CD!Y`(Y````L.$#%:H`X!.1D?G_EX```+0!
M`$`Y/\0`<>`3`%2>_/^7]M)'^<`"0+GG\_^7`0``L&,!@%(B`(!2(:`;D?KS
M_Y>@%0"TN!\`^:$``-`U(`*1H3<`^0$(0/G:`D"YH`9`N3@40/D?!`!Q+1D`
M5+DC`/D9@(!2NW,%J10`@%(S`(!2&02@<@H``!1A"$#YX`,<JOWS_Y>A!D"Y
M(`0`-7,&`!&4!@`1/P`3:ZT#`%3@`QHJQ?/_EP,`@%*"?D"3X0,8JBGT_Y?[
M`P"J(!,`M`,`0/FD!D#YV@)`N6`,0+F<V'/X```9"A\`$'$`_?]4X`,:*K7S
M_Y=A`T#Y0P"`4@(`@-*A\_^7X0,`JN`#'*K>\_^7V@)`N:$&0+D@_/\T(`0`
M41\`%&O@"P!4N.=#J;MS1:G@`QHJI//_EV,`@%(!``"0(@"`4B'`&Y&W\_^7
M\P,`JJ`!`+3TTD?Y@`)`N9KS_Y=A"D#Y`@``D$+@&Y$A`$#Y=?/_EV`*0/D`
M`$#Y``Q`N:`/L#?TTD?Y@`)`N8[S_Y<!``"08P"`4B(`@%(A`!R1H?/_E_,#
M`*J@`0"TH3-`^0```)``@!*1)?G_E_4#`*J``D"Y=0P`M'_S_Y=A"D#YX@,5
MJB$`0/E;\_^7]])'^:`W0/D4(`*1X`)`N7;S_Y?S`P"JX`)`N7/S_Y<B`(!2
M`0``D"$@')&K\_^7`@``D.$#`*I"@!R1X`,3JDKS_Y?@`D"Y://_EQ_D`CFA
M,T#Y````D`!`$I$%^?^7@`H`^?,#`*H`!@"T`3B`4N`#$ZKI\_^7`00`$3\$
M`'$$B%%Z`0H`5*```)`:W$?YH3]`^4`#0/D@``#*X`@`M?-30:GU6T*I]QM`
M^?HG0/G]>\BHP`-?U@`$0#E`[/\T8/__%S\$`'$M]/]4H#=`^3,`@%+UTD?Y
M%"`"D0(``!2Z`D"YX`,:*D#S_Y?A`QBJ^O+_EX`&0+ES!@`1'P`3:PS__U3@
MTD?YN.=#J;MS1:D:`$"YD/__%Z```+#:`D"YH#<`^8S__Q>`!D#YP_S_EX`*
M`/GS`P"JH/G_M0```)"XYP.INW,%J0"@')%G\_^7H3=`^>#21_DA(`*1(01`
MN1H`0+D@!`!1'P`4:P'O_U35__\7'?/_EZ`W0/EB"D#Y`"`"D0$$0/E``$#Y
M(0!`^4#Z_Y>;__\7@`)`N1/S_Y=A"D#Y(0!`^6CS_Y=___\7N!]`^6C__Q>X
MYP.INW,%J1KS_Y>A-T#YXP,`*KMS!:GB`Q.J/"`"D;CG`ZD!``"0($`=D8$'
M0/DA`$#Y/_/_E_U[OJG]`P"1\U,!J?0#`*IF^_^7`0!`.?,#`*K!```T``0`
MD3^\`'%S$H":`0!`.8'__S47_/^7GP(`\0080'J!``!4\U-!J?U[PJC``U_6
M@`)`.8#__S0!``"0@@"`TB&@%Y'@`Q.JR/+_E\#^_S7@`Q2J\U-!J?U[PJA_
M^?\7HP``D&/@1_F#``"T8P!`^9KR_Q<?(`/5`P"`TI?R_Q?]>[RI_0,`D?5;
M`JFU``"0\U,!J;6B+)&T``"0E,(LD90"%<OW8P.I]@,"JO@#`"KW`P&JE/Y#
MDTCR_Y=4`0"T$P"`TJ-Z<_CB`Q:JX0,7JN`#&"IS!@"18``_UI\"$^LA__]4
M\U-!J?5;0JGW8T.I_7O$J,`#7];``U_6_7N_J?T#`)']>\&HP`-?U@`````!
M``(``````'!E<FQX<VDN8P````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@(```````````+@`````````N+@```````"5S+R5S````+W!R
M;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@``````
M26YT97)N86QS.CI005(Z.D)/3U0`````97AE```````O<')O8R\E:2\E<P``
M````4$%27U1%35```````````%!!4E]04D]'3D%-10`````Z`````````"\`
M````````)7,E<R5S``!015),-4Q)0@``````````4$523$Q)0@!015),-4]0
M5```````````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`
M`````%!!4E]#3$5!3@````````!005)?1$5"54<`````````4$%27T-!0TA%
M`````````%!!4E]'3$]"04Q?1$5"54<``````````%!!4E]'3$]"04Q?5$U0
M1$E2`````````%!!4E]435!$25(```````!005)?1TQ/0D%,7U1%35``4$%2
M7T=,3T)!3%]#3$5!3@``````````4$%27T-,14%./0```````#$`````````
M3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>`````!P87(M`````"5S)7,E
M<R5S```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````4$%42``````E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````<&%R;``````N
M<&%R`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E
M;7`M)74M)74E<P``````````05)'5@`````8`````````'!E<FP`````,```
M``````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`T,0```%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*```````````E<P```````"UE````````+2T```````!54T52````
M`%5315).04U%``````````!435!$25(``%1%35!$25(`5$5-4`````!435``
M`````"]T;7``````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D
M>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L
M($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I
M<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@
M(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P
M87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D
M:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@
M)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O
M"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[
M('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*
M<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M
M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D
M978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U
M=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C
M;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@
M("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G
M(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E
M;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M
M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$[
M"G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I
M>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL
M960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L
M("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N
M86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I
M;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\
M?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD
M;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T
M("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(
M+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL
M(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ
M<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA
M;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]
M"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE
M*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D
M9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*
M8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*
M?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B![
M"FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME
M>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D
M+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K
M97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@
M,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T
M96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U
M9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG
M="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D
M9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@
M)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H
M<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD
M9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I
M;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*
M96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E
M8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I
M;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*
M;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D
M<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE
M)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N
M=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N
M=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M
M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK
M*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM
M;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S
M(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%
M050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H
M9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K
M(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O
M<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E
M;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^
M("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI
M("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L
M(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@
M*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F
M:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2![
M"G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN
M8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I
M=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N
M9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,[
M"FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?
M<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#
M;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@
M*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A
M8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O
M7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@
M/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H
M+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*
M;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I
M(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D
M969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@
M:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O
M.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D
M9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT
M.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*
M?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@
M;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&
M24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H
M+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD
M9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%
M4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D
M<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@
M(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D
M8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X]
M(")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H
M+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U
M+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?
M<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E
M;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@
M0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI
M8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I
M<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E
M<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N
M;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97([
M"G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*
M<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A
M;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!
M<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(
M87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R
M97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A
M8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF
M("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O
M9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*
M<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R
M96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]
M"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE
M(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L
M;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*
M?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA
M;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D
M<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D
M=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@
M)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2([
M"F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H
M.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N
M86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@
M)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%4
M2'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@
M97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM
M?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?
M9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!2
M3T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I
M9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]
M"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%
M1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%
M0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D
M14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY
M("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,
M14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]
M*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T
M:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]
M?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I
M9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*
M?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q
M=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O
M;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S
M:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`
M24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD[
M"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE
M("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H
M)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT[
M"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H
M)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?
M7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````*"0```````#@(P``````
M``$``````````0`````````!`````````,L!`````````0`````````:`@``
M``````$`````````<P,````````,`````````*`<````````#0````````#$
M4P```````!D`````````*)L!```````;``````````@`````````&@``````
M```PFP$``````!P`````````"`````````#U_O]O`````&`"````````!0``
M``````"@#0````````8`````````4`,````````*`````````/($````````
M"P`````````8`````````!4````````````````````#`````````%B=`0``
M`````@``````````!@```````!0`````````!P`````````7`````````*`6
M````````!P````````#0$P````````@`````````T`(````````)````````
M`!@`````````'@`````````(`````````/O__V\``````0``"`````#^__]O
M`````'`3````````____;P`````#`````````/#__V\`````DA(```````#Y
M__]O`````!$`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#`'````````,`<````````
MP!P```````#`'````````,`<````````P!P```````#`'````````,`<````
M````P!P```````#`'````````,`<````````P!P```````#`'````````,`<
M````````P!P```````#`'````````,`<````````P!P```````#`'```````
M`,`<````````P!P```````#`'````````,`<````````P!P```````#`'```
M`````,`<````````P!P```````#`'````````,`<````````P!P```````#`
M'````````,`<````````P!P```````#`'````````,`<````````P!P`````
M``#`'````````,`<````````P!P```````#`'````````,`<````````P!P`
M``````#`'````````,`<````````P!P```````#`'````````,`<````````
MP!P```````#`'````````,`<````````P!P```````#`'````````,`<````
M````P!P```````#`'````````,`<````````P!P```````#`'````````,`<
M````````P!P```````#`'````````,`<````````P!P```````#`'```````
M`#B;`0``````P%,`````````````````````````````````````````````
M````````````````````````````````````````````````"*`!````````
M`````````$A3``````````````````#@(```````````````````````````
M````````````````````````"*`!``````#_____`````.A7````````&%0`
M`````````````````'A5````````R%<```````#05P```````-A7````````
MX%<``````````````````+!7````````N%<``````````````````/!7````
M````1T-#.B`H56)U;G1U+TQI;F%R;R`W+C(N,"TQ.75B=6YT=3$I(#<N,BXP
M`$=#0SH@*%5B=6YT=2],:6YA<F\@-BXT+C`M,3%U8G5N='4Q*2`V+C0N,"`R
M,#$W,3(P-@``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T
M92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU
M+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N
M:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N:6YI=%]A<G)A
M>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE
M;G0`````````````````````````````````````````````````````````
M````````````````````````````````````"P````$````"```````````"
M``````````(````````;`````````````````````0``````````````````
M`!,````'`````@`````````<`@```````!P"````````(```````````````
M``````0````````````````````A````!P````(`````````/`(````````\
M`@```````"0````````````````````$````````````````````-````/;_
M_V\"`````````&`"````````8`(```````#L``````````4`````````"```
M`````````````````#X````+`````@````````!0`P```````%`#````````
M4`H````````&`````P````@`````````&`````````!&`````P````(`````
M````H`T```````"@#0```````/($```````````````````!````````````
M````````3@```/___V\"`````````)(2````````DA(```````#<````````
M``4``````````@`````````"`````````%L```#^__]O`@````````!P$P``
M`````'`3````````8``````````&`````P````@```````````````````!J
M````!`````(`````````T!,```````#0$P```````-`"````````!0``````
M```(`````````!@`````````=`````0```!"`````````*`6````````H!8`
M````````!@````````4````4````"``````````8`````````'X````!````
M!@````````"@'````````*`<````````%`````````````````````0`````
M``````````````!Y`````0````8`````````P!P```````#`'````````"`$
M```````````````````0`````````!``````````A`````$````&````````
M`.`@````````X"````````#D,@``````````````````"```````````````
M`````(H````!````!@````````#$4P```````,13````````$```````````
M``````````0```````````````````"0`````0````(`````````V%,`````
M``#84P```````%!````````````````````(````````````````````F```
M``$````"`````````"B4````````*)0````````$````````````````````
M!````````````````````*(````.`````P`````````HFP$``````"B;````
M````"`````````````````````@`````````"`````````"N````#P````,`
M````````,)L!```````PFP````````@````````````````````(````````
M``@`````````N@````8````#`````````#B;`0``````.)L````````@`@``
M``````8`````````"``````````0`````````,,````!`````P````````!8
MG0$``````%B=````````J`(```````````````````@`````````"```````
M``#(`````0````,``````````*`!````````H````````(``````````````
M```````(````````````````````S@````@````#`````````("@`0``````
M@*`````````H$```````````````````"````````````````````-,````!
M````,````````````````````("@````````7P````````````````````$`
M`````````0`````````!`````P````````````````````````#?H```````
A`-P````````````````````!````````````````````
